# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKTransformPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkRigid2DTransformPython
else:
    import _itkRigid2DTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkArray2DPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkMatrixOffsetTransformBasePython

def itkRigid2DTransformD_New():
    return itkRigid2DTransformD.New()

class itkRigid2DTransformD(itk.itkMatrixOffsetTransformBasePython.itkMatrixOffsetTransformBaseD22):
    r"""Proxy of C++ itkRigid2DTransformD class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRigid2DTransformD_Pointer"""
        return _itkRigid2DTransformPython.itkRigid2DTransformD___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRigid2DTransformD_Pointer"""
        return _itkRigid2DTransformPython.itkRigid2DTransformD_Clone(self)

    def SetMatrix(self, *args):
        r"""
        SetMatrix(self, matrix)

        Parameters
        ----------
        matrix: itkMatrixD22 const &

        SetMatrix(self, matrix, tolerance)

        Parameters
        ----------
        matrix: itkMatrixD22 const &
        tolerance: double const

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_SetMatrix(self, *args)

    def Translate(self, offset, pre=False):
        r"""
        Translate(self, offset, pre=False)

        Parameters
        ----------
        offset: itkVectorD2 const &
        pre: bool

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_Translate(self, offset, pre)

    def BackTransform(self, *args):
        r"""
        BackTransform(self, point) -> itkPointD2

        Parameters
        ----------
        point: itkPointD2 const &

        BackTransform(self, vect) -> itkVectorD2

        Parameters
        ----------
        vect: itkVectorD2 const &

        BackTransform(self, vect) -> vnl_vector_fixed< double,2 >

        Parameters
        ----------
        vect: vnl_vector_fixed< double,2 > const &

        BackTransform(self, vect) -> itkCovariantVectorD2

        Parameters
        ----------
        vect: itkCovariantVectorD2 const &

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_BackTransform(self, *args)

    def SetAngle(self, angle):
        r"""
        SetAngle(self, angle)

        Parameters
        ----------
        angle: double

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_SetAngle(self, angle)

    def GetAngle(self):
        r"""GetAngle(self) -> double const &"""
        return _itkRigid2DTransformPython.itkRigid2DTransformD_GetAngle(self)

    def SetAngleInDegrees(self, angle):
        r"""
        SetAngleInDegrees(self, angle)

        Parameters
        ----------
        angle: double

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_SetAngleInDegrees(self, angle)

    def SetRotation(self, angle):
        r"""
        SetRotation(self, angle)

        Parameters
        ----------
        angle: double

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_SetRotation(self, angle)

    def GetRotation(self):
        r"""GetRotation(self) -> double const &"""
        return _itkRigid2DTransformPython.itkRigid2DTransformD_GetRotation(self)

    def CloneInverseTo(self, result):
        r"""
        CloneInverseTo(self, result)

        Parameters
        ----------
        result: itkRigid2DTransformD_Pointer &

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_CloneInverseTo(self, result)

    def GetInverse(self, inverse):
        r"""
        GetInverse(self, inverse) -> bool

        Parameters
        ----------
        inverse: itkRigid2DTransformD *

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_GetInverse(self, inverse)

    def CloneTo(self, result):
        r"""
        CloneTo(self, result)

        Parameters
        ----------
        result: itkRigid2DTransformD_Pointer &

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_CloneTo(self, result)
    __swig_destroy__ = _itkRigid2DTransformPython.delete_itkRigid2DTransformD

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRigid2DTransformD

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRigid2DTransformPython.itkRigid2DTransformD_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRigid2DTransformD

        Create a new object of the class itkRigid2DTransformD and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRigid2DTransformD.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRigid2DTransformD.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRigid2DTransformD.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRigid2DTransformD in _itkRigid2DTransformPython:
_itkRigid2DTransformPython.itkRigid2DTransformD_swigregister(itkRigid2DTransformD)

